=========
tg-pubsub
=========

.. image:: https://img.shields.io/pypi/v/tg-pubsub.svg
        :target: https://pypi.python.org/pypi/tg-pubsub

.. image:: https://img.shields.io/travis/thorgate/tg-pubsub.svg
        :target: https://travis-ci.org/thorgate/tg-pubsub

.. image:: https://readthedocs.org/projects/tg-pubsub/badge/?version=latest
        :target: https://readthedocs.org/projects/tg-pubsub/?badge=latest
        :alt: Documentation Status


Easy pubsub for django models using redis messaging queue.

* Free software: ISC license
* Documentation: https://tg-pubsub.readthedocs.org.

Features
--------

* Can mark own models as listenable
* Can mark external models as listenable
* Builtin pubsub server

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
